
Installation
============

You can either install from pip::

    pip install measurement

*or* checkout and install the source from the `github repository <https://github.com/coddingtonbear/python-measurement/>`_::

    git clone https://github.com/coddingtonbear/python-measurement.git
    cd python-measurement
    python setup.py install

